@@ -2,6 +2,7 @@
 #define DCLOCKSETTINGS_H
 #include <QSize>
 #include <QColor>
+#include <QFont>
 
 class dclocksettings
 {
@@ -22,6 +23,15 @@ public:
     //get/set show seconds flag
     bool getShowSeconds() const;
     void setShowSeconds(const bool &aShow) const;
+    //get/set time format
+    int getTimeFormat() const;
+    void setTimeFormat(const int &aFormatIdx) const;
+    //get/set LCD
+    bool getLcd() const;
+    void setLcd(const bool &aLcd) const;
+    //get/set font
+    QFont getFont() const;
+    void setFont(const QFont &aFont) const;
 
 private:
     dclocksettings() {}
