@@ -5,31 +5,41 @@
 
 //class SettingsDialog;
 
-class DigitalClockWdg : public QLCDNumber
+class DigitalClockWdg : public QWidget
 {
     Q_OBJECT
 
+signals:
+    void updateClock();
+
 public slots:
     void showSettingsDialog();
     void homeScreenChanged(bool isOnCurrentHomescreen);
 
-
 public:
     DigitalClockWdg(QWidget *parent = 0);
 
+protected:
+    void mouseReleaseEvent ( QMouseEvent * e );
+
 private slots:
     void showTime();
 
 private:
     void loadSettings();
+    void initClock();
+    void showClock();
 
 private:
+    QWidget * clk1;
+    bool m_lcd;
+    QFont m_font;
+
     QTimer *m_timer;
     QColor m_digitColor;
-    bool m_showSeconds;
     QSize m_size;
     int m_timer_tick;
-//    SettingsDialog *dialog;
+    QString m_timeFormat;
 };
 
 #endif
